@@ -68,6 +68,8 @@ def make_recursively(src_path,dst_path,config={},overwrite=False):
         make_file(src_path,dst_path,config,overwrite=overwrite)
         print('Render template from %s to %s.' % (src_path,dst_path))
     elif os.path.isdir(src_path):
+        if os.path.basename(src_path)=='__pycache__':
+            return
         if os.path.exists(os.path.join(src_path,WKMAKE_FILENAME)):
             cfg=load_json(os.path.join(src_path,WKMAKE_FILENAME))
             config=check_config(cfg,config)
